@@ -1646,8 +1646,8 @@ def matrix01(df, other_matrix_type, upperleft_diag_matrix_type):
 
     df = df
 
-    print(df.info())
-    plt.figure(figsize=(12, 8))
+    # print(df.info())
+    # plt.figure(figsize=(12, 8))
 
     kind = other_matrix_type;
     diag_kind = upperleft_diag_matrix_type;
